@@ -1,10 +1,16 @@
 #include "kit.h"
 
 static const R_CallMethodDef CallEntries[] = {
+  {"CcountNAR",    (DL_FUNC) &countNAR,    -1},
+  {"CcountR",      (DL_FUNC) &countR,      -1},
   {"CfposR",       (DL_FUNC) &fposR,       -1},
   {"CiifR",        (DL_FUNC) &iifR,        -1},
   {"CnifR",        (DL_FUNC) &nifR,        -1},
   {"CompEnabledR", (DL_FUNC) &ompEnabledR, -1},
+  {"CpanyR",       (DL_FUNC) &panyR,       -1},
+  {"CpallR",       (DL_FUNC) &pallR,       -1},
+  {"CpcountR",     (DL_FUNC) &pcountR,     -1},
+  {"CpmeanR",      (DL_FUNC) &pmeanR,      -1},
   {"CpprodR",      (DL_FUNC) &pprodR,      -1},
   {"CpsumR",       (DL_FUNC) &psumR,       -1},
   {"CsetlevelsR",  (DL_FUNC) &setlevelsR,  -1},
@@ -18,9 +24,15 @@ void R_init_kit(DllInfo *dll)
 {
   R_registerRoutines(dll, NULL, CallEntries, NULL, NULL);
   R_useDynamicSymbols(dll, FALSE);
+  R_RegisterCCallable("kit", "CcountNAR",    (DL_FUNC) &countNAR);
+  R_RegisterCCallable("kit", "CcountR",      (DL_FUNC) &countR);
   R_RegisterCCallable("kit", "CfposR",       (DL_FUNC) &fposR);
   R_RegisterCCallable("kit", "CiifR",        (DL_FUNC) &iifR);
   R_RegisterCCallable("kit", "CnifR",        (DL_FUNC) &nifR);
+  R_RegisterCCallable("kit", "CpanyR",       (DL_FUNC) &panyR);
+  R_RegisterCCallable("kit", "CpallR",       (DL_FUNC) &pallR);
+  R_RegisterCCallable("kit", "CpcountR",     (DL_FUNC) &pcountR);
+  R_RegisterCCallable("kit", "CmeanR",       (DL_FUNC) &pmeanR);
   R_RegisterCCallable("kit", "CpprodR",      (DL_FUNC) &pprodR);
   R_RegisterCCallable("kit", "CpsumR",       (DL_FUNC) &psumR);
   R_RegisterCCallable("kit", "CsetlevelsR",  (DL_FUNC) &setlevelsR);
