@@ -1,10 +1,14 @@
 #include <R.h>
-#include <Rinternals.h>
 #include <R_ext/Rdynload.h>
+#include <Rversion.h>
+#if !defined(R_VERSION) || R_VERSION < R_Version(3, 5, 0)
+  #define USE_RINTERNALS
+  #define DATAPTR_RO(x) ((const void *)DATAPTR(x))
+#endif
+#include <Rinternals.h>
 #include <stdlib.h>
 #include <stdint.h>
 #include <stdbool.h>
-
 #ifdef _OPENMP
   #include<omp.h>
   #define omp_enabled true
@@ -29,10 +33,16 @@
 #define EQUAL_CPLX(x, y) (((x.r) == (y.r)) && ((x.i) == (y.i)))
 #define RCHAR(x, y) CHAR(STRING_ELT(x, y))
 
+extern SEXP countR(SEXP x, SEXP y);
+extern SEXP countNAR(SEXP x);
 extern SEXP fposR(SEXP needle, SEXP haystack, SEXP all, SEXP overlap);
 extern SEXP iifR(SEXP l, SEXP a, SEXP b, SEXP na, SEXP tprom, SEXP nthreads);
 extern SEXP nifR(SEXP na, SEXP rho, SEXP md, SEXP args);
 extern SEXP ompEnabledR();
+extern SEXP pallR(SEXP na, SEXP args);
+extern SEXP panyR(SEXP na, SEXP args);
+extern SEXP pcountR(SEXP x, SEXP args);
+extern SEXP pmeanR(SEXP na, SEXP args);
 extern SEXP pprodR(SEXP na, SEXP args);
 extern SEXP psumR(SEXP na, SEXP args);
 extern SEXP setlevelsR(SEXP x, SEXP old_lvl, SEXP new_lvl, SEXP skip_absent);
@@ -40,6 +50,5 @@ extern SEXP topnR(SEXP vec, SEXP n, SEXP dec);
 extern SEXP uniquePR(SEXP x);
 extern SEXP vswitchR(SEXP x, SEXP values, SEXP outputs, SEXP na, SEXP nthreads);
 
-Rboolean hasNA(SEXP x);
-R_xlen_t countNA(SEXP x);
-SEXP removeNA(SEXP x);
+//Rboolean hasNA(SEXP x);
+//SEXP removeNA(SEXP x);
